.. _ref-code:

Code Documentation
==================

db_mutex
--------

.. automodule:: db_mutex.db_mutex
.. autoclass:: db_mutex.db_mutex.db_mutex
    :members:

    .. automethod:: __init__

DBMutex Model
-------------

.. autoclass:: db_mutex.models.DBMutex
    :members:

Exceptions
----------

.. automodule:: db_mutex.exceptions
.. autoclass:: db_mutex.exceptions.DBMutexError
.. autoclass:: db_mutex.exceptions.DBMutexTimeoutError
